mbr

package
v0.0.0-...-712dae0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 16, 2024 License: BSD-3-Clause Imports: 3 Imported by: 0

Documentation

Overview

Package mbr provides a configured version of Sebastian Plotz’s minimal stage1-only Linux bootloader, to be written to a Master Boot Record.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Configure

func Configure(vmlinuzLba, cmdlineLba uint32, partuuid uint32) [446]byte

Types

This section is empty.

Jump to